// KreateCD - CD recording software for the K desktop environment
//
// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
//
// This file is subject to the terms and conditions of the GNU General
// Public License.  See the file COPYING in the main directory of the
// KreateCD distribution for more details.

#ifndef CDPARANOIA_INCLUDED
#define CDPARANOIA_INCLUDED

#include "AudioRipper.h"


class CDParanoia : public AudioRipper {
  Q_OBJECT
    protected:
  virtual bool doRip(int track,const char *filename);
  virtual bool processStderrLine(char *linebuffer);

 private:
  int paranoiafrom,paranoiato;
};


#endif
